# What do you need to access the output database?

To use the Abaqus C++ API to access an output database, you need to understand the following:

- The fundamentals of Abaqus output data and the Abaqus concepts of instances, fields, and history.
- How to program in C++.
- How to use the C++ API utility interface.
- How to use Abaqus objects.
- How to compile and link your C++ source code.
